==> general_lib-0.0.35.tar.gz: lib/script_generate/script_generate.dart <==
// ignore_for_file: unused_local_variable, unnecessary_brace_in_string_interps, unnecessary_string_interpolations

/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!

Jika ada kendala program ini (Pastikan sebelum deal project tidak ada negosiasi harga)
Karena jika ada negosiasi harga kemungkinan

1. Software Ada yang di kurangin
2. Informasi tidak lengkap
3. Bantuan Tidak Bisa remote / full time (Ada jeda)

Sebelum program ini sampai ke pembeli developer kami sudah melakukan testing

jadi sebelum nego kami sudah melakukan berbagai konsekuensi jika nego tidak sesuai ? 
Bukan maksud kami menipu itu karena harga yang sudah di kalkulasi + bantuan tiba tiba di potong akhirnya bantuan / software kadang tidak lengkap


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names

import 'dart:async';
import 'dart:convert';

import 'package:collection/collection.dart';
import 'package:general_lib/extension/dynamic.dart';
import 'package:general_lib/extension/string.dart';
import 'package:general_lib/file_system_entity/file_system_entity.dart';
import 'package:general_lib/regexp_replace/regexp_replace.dart';
import 'package:universal_io/io.dart';

import "package:path/path.dart" as path;

extension ExtensionOnStorSapsapslpaTtpe on List<FileSystemEntity> {
  List<ScriptGenerator> toScriptGenerate({
    Directory? directoryBase,
  }) {
    List<ScriptGenerator> sles = [];

    local_sort();
    FileSystemEntity? fileSystemEntity_base = firstWhereOrNull((element) {
      if (element is Directory) {
        return true;
      }
      return false;
    });

    Directory directory = () {
      if (directoryBase != null) {
        return directoryBase;
      }
      if (fileSystemEntity_base != null) {
        return fileSystemEntity_base.parent;
      }
      return Directory.current;
    }();
    for (var i = 0; i < length; i++) {
      FileSystemEntity fileSystemEntity = this[i];

      if (fileSystemEntity is File) {
        File file = File(fileSystemEntity.uri.toFilePath());
        String data = "";
        try {
          data = file.readAsStringSync();
        } catch (e) {
          continue;
        }
        sles.add(ScriptGenerator(
          is_generate: false,
          directory_base: directory,
          fileSystemEntity: fileSystemEntity,
          state_data: {},
          value: data,
          fileSystemEntityType: fileSystemEntity.statSync().type,
          children: [],
        ));
      } else if (fileSystemEntity is Directory) {
        String base_name = path.basename(fileSystemEntity.uri.toFilePath());
        if (RegExp(r"^([.])", caseSensitive: false).hasMatch(base_name)) {
          if ([".github", ".idea"].contains(base_name) == false) {
            continue;
          }
        }
        sles.add(ScriptGenerator(
          is_generate: false,
          directory_base: directory,
          fileSystemEntity: fileSystemEntity,
          state_data: {},
          value: "",
          fileSystemEntityType: fileSystemEntity.statSync().type,
          children: fileSystemEntity
              .listSync()
              .toScriptGenerate(directoryBase: directory),
        ));
      } else {
        String base_name = path.basename(fileSystemEntity.uri.toFilePath());
        if (RegExp(r"^([.])", caseSensitive: false).hasMatch(base_name)) {
          continue;
        }
        sles.add(ScriptGenerator(
          is_generate: false,
          directory_base: directory,
          fileSystemEntity: fileSystemEntity,
          state_data: {},
          value: "",
          fileSystemEntityType: fileSystemEntity.statSync().type,
          children: [],
        ));
      }
    }
    return sles;
  }
}

typedef OnWrittingScriptGenerator = FutureOr<String> Function(
    ScriptGenerator scriptGenerator, File file);

extension FileSaloslapsExtension on List<ScriptGenerator> {
  FutureOr<dynamic> generateToDirectory({
    required Directory directoryBase,
    OnWrittingScriptGenerator? onWritting,
  }) async {
    // String base_path = directoryNew.uri.toFilePath();
    Directory directory_base = Directory(directoryBase.uri.toFilePath());
    String base_name = path.basename(directory_base.path);
    if (directory_base.existsSync() == false) {
      await directory_base.create(
        recursive: true,
      );
    }
    for (ScriptGenerator scriptGenerator in this) {
      if (scriptGenerator.fileSystemEntityType == FileSystemEntityType.file) {
        String path_origin_file = () {
          if ((path
                  .basename(scriptGenerator.directory_base.uri.toFilePath())
                  .toLowerCase() ==
              path
                  .basenameWithoutExtension(
                      scriptGenerator.fileSystemEntity.uri.toFilePath())
                  .toLowerCase())) {
            String result_path = "";
            if (scriptGenerator.is_generate) {
              result_path = scriptGenerator.fileSystemEntity.uri.toFilePath();
            } else {
              result_path = path.relative(
                scriptGenerator.fileSystemEntity.uri.toFilePath(),
                from: scriptGenerator.directory_base.uri.toFilePath(),
              );
            }
            // change name origin if same to new file name
            return result_path.replaceAll(
                path.basename(scriptGenerator.directory_base.uri.toFilePath()),
                base_name);
          } else {
            String result_path = "";
            if (scriptGenerator.is_generate) {
              result_path = scriptGenerator.fileSystemEntity.uri.toFilePath();
            } else {
              result_path = path.relative(
                scriptGenerator.fileSystemEntity.uri.toFilePath(),
                from: scriptGenerator.directory_base.uri.toFilePath(),
              );
            }
            // change name origin if same to new file name
            return result_path.replaceAll(
                path.basename(scriptGenerator.directory_base.uri.toFilePath()),
                base_name);
          }
        }();

        File file =
            File(path.join(directory_base.uri.toFilePath(), path_origin_file));
        if (file.parent.existsSync() == false) {
          file.parent.createSync(recursive: true);
        }
        OnWrittingScriptGenerator? onWrittingScriptGenerator_script =
            onWritting;
        if (onWrittingScriptGenerator_script != null) {
          await file.writeAsString(
              (await onWrittingScriptGenerator_script(scriptGenerator, file)));
        } else {
          // await file.writeAsString(scriptGenerator.value.replaceAll(path.basename(scriptGenerator.directory_base.uri.toFilePath()), base_name));
          await file.writeAsString(replacerData(
              value: scriptGenerator.value,
              originProjectName: path
                  .basename(scriptGenerator.directory_base.uri.toFilePath()),
              newProjectName: base_name));
        }
      } else if (scriptGenerator.fileSystemEntityType ==
          FileSystemEntityType.directory) {
        await scriptGenerator.children.generateToDirectory(
          directoryBase: directory_base,
          onWritting: onWritting,
        );
      } else {}
    }

    return;
  }

  String replacerData({
    required String value,
    required String originProjectName,
    required String newProjectName,
  }) {
    value = value.replaceAll(originProjectName, newProjectName);
    List<RegExpReplace> regExpReplaces = [
      // example:
      // SlebewProject
      // NewProject
      RegExpReplace(
        from: RegExp(originProjectName.camelCaseClass()),
        replace: (match) {
          return newProjectName.camelCaseClass();
        },
      ),
      // example:
      // slebewProject
      // newProject
      RegExpReplace(
        from: RegExp(originProjectName.camelCaseClass().toLowerCaseFirstData()),
        replace: (match) {
          return newProjectName.camelCaseClass().toLowerCaseFirstData();
        },
      ),
      // example:
      // Slebew Project
      // New Project
      RegExpReplace(
        from: RegExp(originProjectName.snakeCaseClass().split("_").join(" "),
            caseSensitive: false),
        replace: (match) {
          return newProjectName
              .snakeCaseClass()
              .split("_")
              .map((e) => e.toUpperCaseFirstData())
              .join(" ");
        },
      ),
    ];
    for (var i = 0; i < regExpReplaces.length; i++) {
      RegExpReplace regExpReplace = regExpReplaces[i];
      value = value.replaceAllMapped(regExpReplace.from, regExpReplace.replace);
    }
    return value;
  }

  List<Map> toJson() {
    return map((e) => e.toJson()).toList(
      growable: true,
    );
  }

  String toStringData() {
    return (toJson().toStringifyPretty());
  }

  String toScriptDart({
    required String scriptName,
  }) {
    String script_dart_generate = """
// ignore_for_file: non_constant_identifier_names

// import 'dart:io';
import 'package:general_lib/script_generate/script_generate.dart';
import 'package:universal_io/io.dart';

List<ScriptGenerator> ${scriptName}_script_generators = [
  ${map((e) => e.toScriptDart()).join(",\n")}
];
 
""";
    return script_dart_generate;
  }
}

class ScriptGenerator {
  FileSystemEntity fileSystemEntity;
  Map state_data = {};
  Directory directory_base;
  String value;
  FileSystemEntityType fileSystemEntityType;
  List<ScriptGenerator> children;
  bool is_generate;
  ScriptGenerator({
    required this.is_generate,
    required this.directory_base,
    required this.fileSystemEntity,
    required this.state_data,
    required this.fileSystemEntityType,
    required this.value,
    required this.children,
  });

  String getPath() {
    return path.relative(fileSystemEntity.uri.toFilePath(),
        from: directory_base.uri.toFilePath());
  }

  Map toJson() {
    return {
      "@type": "ScriptGenerator",
      "directory_base": directory_base.path,
      "path": getPath(),
      "type": fileSystemEntityType.toString(),
      "value": value,
      "children": children.map((e) => e.toJson()).toList(growable: true),
    };
  }

  String toScriptDart() {
    String parse_value =
        (value).replaceAllMapped(RegExp(r"((.)?(\$))"), (match) {
      String gro = match.group(2) ?? "";
      String gall = match.group(1) ?? "";

      // if (gro != "\\") {
      //   return "\\${gall}";
      // }
      return "${gall}";
    });
    String script_generate = """
ScriptGenerator(
  is_generate: true,
  directory_base: Directory(${json.encode(path.basename(directory_base.uri.toFilePath()))}),
  fileSystemEntity: ${() {
      String base_file_path = path.relative(fileSystemEntity.uri.toFilePath(),
          from: directory_base.uri.toFilePath());
      if (fileSystemEntityType == FileSystemEntityType.file) {
        return "File(${json.encode(base_file_path)})";
      }
      return "Directory(${json.encode(base_file_path)})";
    }()},
  state_data: {},
  fileSystemEntityType: FileSystemEntityType.${fileSystemEntityType.toString()},
  value: r\"\"\"${parse_value}\"\"\",
  children: [
    ${children.map((e) => e.toScriptDart()).join(",\n    ")}
  ],
)
""";
    // RegExp.escape(text);

    return script_generate.trim();
  }

  @override
  String toString() {
    return json.encode(toJson());
  }
}

==> general_lib-0.0.36.tar.gz: lib/script_generate/script_generate.dart <==
// ignore_for_file: unused_local_variable, unnecessary_brace_in_string_interps, unnecessary_string_interpolations

/* <!-- START LICENSE -->


Program Ini Di buat Oleh DEVELOPER Dari PERUSAHAAN GLOBAL CORPORATION 
Social Media: 

- Youtube: https://youtube.com/@Global_Corporation 
- Github: https://github.com/globalcorporation
- TELEGRAM: https://t.me/GLOBAL_CORP_ORG_BOT

Seluruh kode disini di buat 100% murni tanpa jiplak / mencuri kode lain jika ada akan ada link komment di baris code

Jika anda mau mengedit pastikan kredit ini tidak di hapus / di ganti!

Jika Program ini milik anda dari hasil beli jasa developer di (Global Corporation / apapun itu dari turunan itu jika ada kesalahan / bug / ingin update segera lapor ke sub)

Misal anda beli Beli source code di Slebew CORPORATION anda lapor dahulu di slebew jangan lapor di GLOBAL CORPORATION!

Jika ada kendala program ini (Pastikan sebelum deal project tidak ada negosiasi harga)
Karena jika ada negosiasi harga kemungkinan

1. Software Ada yang di kurangin
2. Informasi tidak lengkap
3. Bantuan Tidak Bisa remote / full time (Ada jeda)

Sebelum program ini sampai ke pembeli developer kami sudah melakukan testing

jadi sebelum nego kami sudah melakukan berbagai konsekuensi jika nego tidak sesuai ? 
Bukan maksud kami menipu itu karena harga yang sudah di kalkulasi + bantuan tiba tiba di potong akhirnya bantuan / software kadang tidak lengkap


<!-- END LICENSE --> */
// ignore_for_file: non_constant_identifier_names

import 'dart:async';
import 'dart:convert';

import 'package:collection/collection.dart';
import 'package:general_lib/extension/dynamic.dart';
import 'package:general_lib/extension/string.dart';
import 'package:general_lib/file_system_entity/file_system_entity.dart';
import 'package:general_lib/regexp_replace/regexp_replace.dart';
import 'package:universal_io/io.dart';

import "package:path/path.dart" as path;

extension ExtensionOnStorSapsapslpaTtpe on List<FileSystemEntity> {
  List<ScriptGenerator> toScriptGenerate({
    Directory? directoryBase,
    bool isVerbose = false,
  }) {
    List<ScriptGenerator> sles = [];

    local_sort();
    FileSystemEntity? fileSystemEntity_base = firstWhereOrNull((element) {
      if (element is Directory) {
        return true;
      }
      return false;
    });

    Directory directory = () {
      if (directoryBase != null) {
        return directoryBase;
      }
      if (fileSystemEntity_base != null) {
        return fileSystemEntity_base.parent;
      }
      return Directory.current;
    }();
    for (var i = 0; i < length; i++) {
      FileSystemEntity fileSystemEntity = this[i];

      if (fileSystemEntity is File) {
        String base_name = path.basename(fileSystemEntity.uri.toFilePath());
        if (["pubspec.lock"].contains(base_name.toLowerCase().trim())) {
          if (isVerbose) {
            print(
                "SKIP ON FILE: ${fileSystemEntity.statSync().type} ${path.relative(fileSystemEntity.uri.toFilePath(), from: directory.path)}");
          }
          continue;
        }
        List<String> paths_folders =
            path.split(fileSystemEntity.uri.toFilePath());
        if (paths_folders.contains(".dart_tool")) {
          if (isVerbose) {
            print(
                "SKIP ON FILE: ${fileSystemEntity.statSync().type} ${path.relative(fileSystemEntity.uri.toFilePath(), from: directory.path)}");
          }
          continue;
        }

        File file = File(fileSystemEntity.uri.toFilePath());
        String data = "";
        try {
          data = file.readAsStringSync();
        } catch (e) {
          continue;
        }
        sles.add(ScriptGenerator(
          is_generate: false,
          directory_base: directory,
          file_system_entity: fileSystemEntity,
          state_data: {},
          value: data,
          file_system_entity_type: fileSystemEntity.statSync().type,
          children: [],
        ));
      } else if (fileSystemEntity is Directory) {
        String base_name = path.basename(fileSystemEntity.uri.toFilePath());
        List<String> paths_folders =
            path.split(fileSystemEntity.uri.toFilePath());
        if (RegExp(r"^([.])", caseSensitive: false).hasMatch(base_name)) {
          if ([".github", ".idea"].contains(base_name) == false) {
            continue;
          }
        }
        if (paths_folders.contains(".dart_tool")) {
          if (isVerbose) {
            print(
                "SKIP ON DIR: ${fileSystemEntity.statSync().type} ${path.relative(fileSystemEntity.uri.toFilePath(), from: directory.path)}");
          }
          continue;
        }
        sles.add(ScriptGenerator(
          is_generate: false,
          directory_base: directory,
          file_system_entity: fileSystemEntity,
          state_data: {},
          value: "",
          file_system_entity_type: fileSystemEntity.statSync().type,
          children: fileSystemEntity
              .listSync()
              .toScriptGenerate(directoryBase: directory, isVerbose: isVerbose),
        ));
      } else {
        String base_name = path.basename(fileSystemEntity.uri.toFilePath());
        if (RegExp(r"^([.])", caseSensitive: false).hasMatch(base_name)) {
          continue;
        }
        sles.add(ScriptGenerator(
          is_generate: false,
          directory_base: directory,
          file_system_entity: fileSystemEntity,
          state_data: {},
          value: "",
          file_system_entity_type: fileSystemEntity.statSync().type,
          children: [],
        ));
      }
    }
    return sles;
  }
}

typedef OnWrittingScriptGenerator = FutureOr<String> Function(
    ScriptGenerator scriptGenerator, File file);

extension FileSaloslapsExtension on List<ScriptGenerator> {
  FutureOr<dynamic> generateToDirectory({
    required Directory directoryBase,
    OnWrittingScriptGenerator? onWritting,
    bool isSkipAutoRename = false,
  }) async {
    // String base_path = directoryNew.uri.toFilePath();
    Directory directory_base = Directory(directoryBase.uri.toFilePath());
    String base_name = path.basename(directory_base.path);
    if (directory_base.existsSync() == false) {
      await directory_base.create(
        recursive: true,
      );
    }
    for (ScriptGenerator scriptGenerator in this) {
      if (scriptGenerator.file_system_entity_type ==
          FileSystemEntityType.file) {
        String path_origin_file = () {
          if ((path
                  .basename(scriptGenerator.directory_base.uri.toFilePath())
                  .toLowerCase() ==
              path
                  .basenameWithoutExtension(
                      scriptGenerator.file_system_entity.uri.toFilePath())
                  .toLowerCase())) {
            String result_path = "";
            if (scriptGenerator.is_generate) {
              result_path = scriptGenerator.file_system_entity.uri.toFilePath();
            } else {
              result_path = path.relative(
                scriptGenerator.file_system_entity.uri.toFilePath(),
                from: scriptGenerator.directory_base.uri.toFilePath(),
              );
            }
            // change name origin if same to new file name
            // return result_path.replaceAll(path.basename(scriptGenerator.directory_base.uri.toFilePath()), base_name);
            return ScriptGenerator.replacerData(
              value: result_path,
              originProjectName: path
                  .basename(scriptGenerator.directory_base.uri.toFilePath()),
              newProjectName: base_name,
              isSkipAutoRename: isSkipAutoRename,
            );
          } else {
            String result_path = "";
            if (scriptGenerator.is_generate) {
              result_path = scriptGenerator.file_system_entity.uri.toFilePath();
            } else {
              result_path = path.relative(
                scriptGenerator.file_system_entity.uri.toFilePath(),
                from: scriptGenerator.directory_base.uri.toFilePath(),
              );
            }
            // change name origin if same to new file name
            // old work
            // return result_path.replaceAll(path.basename(scriptGenerator.directory_base.uri.toFilePath()), base_name);
            return ScriptGenerator.replacerData(
              value: result_path,
              originProjectName: path
                  .basename(scriptGenerator.directory_base.uri.toFilePath()),
              newProjectName: base_name,
              isSkipAutoRename: isSkipAutoRename,
            );
          }
        }();

        File file =
            File(path.join(directory_base.uri.toFilePath(), path_origin_file));
        if (file.parent.existsSync() == false) {
          file.parent.createSync(recursive: true);
        }
        OnWrittingScriptGenerator? onWrittingScriptGenerator_script =
            onWritting;
        if (onWrittingScriptGenerator_script != null) {
          await file.writeAsString(
              (await onWrittingScriptGenerator_script(scriptGenerator, file)));
        } else {
          // await file.writeAsString(scriptGenerator.value.replaceAll(path.basename(scriptGenerator.directory_base.uri.toFilePath()), base_name));
          await file.writeAsString(ScriptGenerator.replacerData(
              value: scriptGenerator.value,
              originProjectName: path
                  .basename(scriptGenerator.directory_base.uri.toFilePath()),
              newProjectName: base_name,
              isSkipAutoRename: isSkipAutoRename));
        }
      } else if (scriptGenerator.file_system_entity_type ==
          FileSystemEntityType.directory) {
        await scriptGenerator.children.generateToDirectory(
          directoryBase: directory_base,
          onWritting: onWritting,
        );
      } else {}
    }

    return;
  }

  Map toJson() {
    List<Map> scripts = map((e) => e.toJson()).toList(
      growable: true,
    );
    return {
      "@type": "scripts",
      "total_count": scripts.length,
      "scripts": scripts,
    };
  }

  List<Map> toJsonList() {
    List<Map> scripts = map((e) => e.toJson()).toList(
      growable: true,
    );
    return scripts;
  }

  String toStringData() {
    return (toJsonList().toStringifyPretty());
  }

  String toScriptDart({
    required String scriptName,
  }) {
    String script_dart_generate = """
// ignore_for_file: non_constant_identifier_names

// import 'dart:io';
import 'package:general_lib/script_generate/script_generate.dart';
import 'package:universal_io/io.dart';

List<ScriptGenerator> ${scriptName}_script_generators = [
  ${map((e) => e.toScriptDart()).join(",\n")}
];
 
""";
    return script_dart_generate;
  }
}

class ScriptGenerator {
  FileSystemEntity file_system_entity;
  Map state_data = {};
  Directory directory_base;
  String value;
  FileSystemEntityType file_system_entity_type;
  List<ScriptGenerator> children;
  bool is_generate;
  ScriptGenerator({
    required this.is_generate,
    required this.directory_base,
    required this.file_system_entity,
    required this.state_data,
    required this.file_system_entity_type,
    required this.value,
    required this.children,
  });

  static String replacerData({
    required String value,
    required String originProjectName,
    required String newProjectName,
    required bool isSkipAutoRename,
  }) {
    if (isSkipAutoRename) {
      return value;
    }
    value = value.replaceAll(originProjectName, newProjectName);
    List<RegExpReplace> regExpReplaces = [
      // example:
      // SlebewProject
      // NewProject
      RegExpReplace(
        from: RegExp(originProjectName.camelCaseClass()),
        replace: (match) {
          return newProjectName.camelCaseClass();
        },
      ),
      // example:
      // slebewProject
      // newProject
      RegExpReplace(
        from: RegExp(originProjectName.camelCaseClass().toLowerCaseFirstData()),
        replace: (match) {
          return newProjectName.camelCaseClass().toLowerCaseFirstData();
        },
      ),
      // example:
      // Slebew Project
      // New Project
      RegExpReplace(
        from: RegExp(originProjectName.snakeCaseClass().split("_").join(" "),
            caseSensitive: false),
        replace: (match) {
          return newProjectName
              .snakeCaseClass()
              .split("_")
              .map((e) => e.toUpperCaseFirstData())
              .join(" ");
        },
      ),
    ];
    for (var i = 0; i < regExpReplaces.length; i++) {
      RegExpReplace regExpReplace = regExpReplaces[i];
      value = value.replaceAllMapped(regExpReplace.from, regExpReplace.replace);
    }
    return value;
  }

  String getPath() {
    return path.relative(file_system_entity.uri.toFilePath(),
        from: directory_base.uri.toFilePath());
  }

  Map toJson() {
    return {
      "@type": "ScriptGenerator",
      "is_generate": true,
      "directory_base": (path.basename(directory_base.uri.toFilePath())),
      "file_system_entity": path.relative(file_system_entity.uri.toFilePath(),
          from: directory_base.uri.toFilePath()),
      "file_system_entity_type": file_system_entity_type.toString(),
      "value": value,
      "children": children.map((e) => e.toJson()).toList(growable: true),
    };
  }

  String toScriptDart() {
    String parse_value =
        (value).replaceAllMapped(RegExp(r"((.)?(\$))"), (match) {
      String gro = match.group(2) ?? "";
      String gall = match.group(1) ?? "";

      // if (gro != "\\") {
      //   return "\\${gall}";
      // }
      return "${gall}";
    });
    String script_generate = """
ScriptGenerator(
  is_generate: true,
  directory_base: Directory(${json.encode(path.basename(directory_base.uri.toFilePath()))}),
  file_system_entity: ${() {
      String base_file_path = path.relative(file_system_entity.uri.toFilePath(),
          from: directory_base.uri.toFilePath());
      if (file_system_entity_type == FileSystemEntityType.file) {
        return "File(${json.encode(base_file_path)})";
      }
      return "Directory(${json.encode(base_file_path)})";
    }()},
  state_data: {},
  file_system_entity_type: FileSystemEntityType.${file_system_entity_type.toString()},
  value: r\"\"\"${parse_value}\"\"\",
  children: [
    ${children.map((e) => e.toScriptDart()).join(",\n    ")}
  ],
)
""";
    // RegExp.escape(text);

    return script_generate.trim();
  }

  @override
  String toString() {
    return json.encode(toJson());
  }
}
